@@ -5,27 +5,38 @@ import socket
 import time
 import zmq
 
+from tornado.options import define, options, parse_command_line, print_help
 from uuid import uuid4
 
-COLLECTOR_HOST = "127.0.0.1"
+COLLECTOR_ADDRESS = "127.0.0.1"
 COLLECTOR_PORT = 49999
 CONFIG_PATH = "/etc/tenderloin"
 DEFAULT_TAGS = []
 
 
 class TenderloinPlugin(object):
-    def __init__(self, name, interval=60, collector_host=COLLECTOR_HOST,
-                 collector_port=COLLECTOR_PORT, tags=DEFAULT_TAGS):
-        global COLLECTOR_HOST, COLLECTOR_PORT, CONFIG_PATH
+    def __init__(self, name, tags=DEFAULT_TAGS):
+        global COLLECTOR_ADDRESS, COLLECTOR_PORT, CONFIG_PATH
+
+        define("hostname", default=socket.getfqdn(), group="plugin",
+               help="Hostname to report as")
+        define("collector_address", default=COLLECTOR_ADDRESS, group="plugin",
+               help="Tenderloin collector address")
+        define("collector_port", default=COLLECTOR_PORT, group="plugin",
+               help="Tenderloin collector port")
+        define("interval", default=60, group="plugin",
+               help="Query interval")
+
+        parse_command_line()
 
         self.name = name
-        self.interval = interval
         self.config = self._parse_config(os.path.join(CONFIG_PATH, "%s.ini" %
                                                       self.name))
-        self.whoami = (self.name, str(uuid4()), socket.getfqdn())
+        self.interval = options.interval
+        self.whoami = (self.name, str(uuid4()), options.hostname)
         self.tags = set(tags) | set([self.whoami[0], self.whoami[2]])
-        self._worker_socket = self._get_worker_socket(collector_host,
-                                                      collector_port)
+        self._worker_socket = self._get_worker_socket(options.collector_address,
+                                                      options.collector_port)
         self._metrics = {}
 
     def __iter__(self):
